/*------------------------------------------------------------------------------
 *
 *	Apple Macintosh Developer Technical Support
 *
 *  Installer 3.4 sample: simple installation (Supports Easy and Custom Installation)
 *
 *	File:		CustomFoldIconInstall.r -	Rez Source
 *	Description: Custom folder icons result when there is a file of name "Icon\n" in a
 *					folder, whose finder info flags have the "Use Custom Icon" bit set
 *					Additionally, the "Icon\n" file contains an 'icl4', 'icl8', 'ICN#,
 *					'ics#', 'ics4', and 'ics8' resource each with ID -16455.  Normally
 *					the icon file has the invisible bit set.  In this sample, the 
 *					Icon file is installed using an 'infa' file atom.  The invisible bit
 *					remains set during the install.  A post-installation action atom
 *					is then called being passed the resource ID of the 'infs' file
 *					spec for the target icon.  The code resource strips the file name
 *					and uses File Manager calls to get and set the Finder info for the 
 *					folder.
 *
 *	by:			Rich Kubota
 *	modifications:
 *				rrk - 5/19/93 modified target file atoms to show that the date
 *						time stamp field must be zero, and that the file/creator
 *						should not match. Also use InstallerCommon.r file 
 *				rrk - 9/8/92 updated the inaa resource to format1 from format0
 *						added the "continueBusyCursors" flag to the inaa.
 *
 *	Copyright  1992 Apple Computer, Inc.
 *	All rights reserved.
 *
 *------------------------------------------------------------------------------
 *
 * Install application "TeachText" into the folder "Root":Installed Application.
 * It demonstrates how to implement a Custom Folder Icon.  
 *----------------------------------------------------------------------------*/

#include "Types.r"					/* for the ICON resource */
#include "InstallerTypes.r"
#include "InstallerCommon.r"		/* list of macros to simplify list */

/* You can build and complete the script with the following lines:
# Note: set up floppies with the appropriate names and contents before running scriptcheck
# or set up folders with the same names and contents as the floppies
# put these folders in the same folder as the script or at the root directory of same disk

	rez -o "CustomFoldIconInstall" -t 'bbkr' -c 'bbkr' "CustomFoldIconInstall.r"
	setfile -a i "CustomFoldIconInstall"		#mark Inited
	scriptcheck -p "CustomFoldIconInstall"
*/

/* Definitions for the rules */
#define rlInstallProgram		1000

/* Defines for the file spec atoms (specifications for source and destination files) */
#define fsSourceProgram			2000
#define fsTargetProgram			2001
#define fsSourceIcon			2002
#define fsTargetIcon			2003

/* This is the name of the source disk */
#define ProgramDisk "Program Disk:"

/* where we want to install our file. */
#define TargetPath	":Installed Application:"

/* Definition for the package. */
#define pkTheProgram			3000

/* Definition for the file atom */
#define faProgram				4000
#define faIcon					4001

/* Definition for the package comment resource */
#define cmtTheProgram			5000

/* Definitions for the action atom resources */
#define aaSetFolderIcon			6000

/* 'inaa' code resource definition */
#define		aaCodeID			10000

/* May 19, 1993 is the current release date I put in 'icmt' rsrcs. ScriptCheck will convert */
/* this value to a LongInt seconds value needed by the Installer. */
#define currentReleaseDate		5191993	
#define currentVersion			102 	/* Version 1.0.2 goes in the 'icmt' rsrc */

#define iconTheProgram			5100

/************************** Easy Install Rule resources **********************************/
resource 'infr' (1) {
	format0  {{
		pickFirst,	{rlInstallProgram},	 /* Only one rule */
	}};
};

resource 'inrl' (rlInstallProgram) {
	format0 {{
		addUserDescription {"Click Install to install\n"},	/* message to appear in Easy Install screen */
		addUserDescription {"The Program in custom folder\n"},	/* message to appear in Easy Install screen */
		addPackages {{pkTheProgram}}			/* we're installing the program */
	}};
};

/***************************** Package Resources ************************************************/
resource 'inpk' (pkTheProgram) {
	format0 {
		showsOnCustom, 				/* Package appears in the Custom Install display */
		removable,					/* Package can be removed */
		dontForceRestart,			/* no need to reboot after live install */
		cmtTheProgram, 				/* package's 'icmt' resource id */
		0,							/* Package size (filled in by ScriptCheck) */
		"TheProgram", {				/* package name for package that shows on custom */
			'infa', faProgram;
			'infa', faIcon;
			'inaa', aaSetFolderIcon;
		}
	}
};

/***************************** Comments ************************************************/
resource 'icmt' (cmtTheProgram) {
	currentReleaseDate,
	currentVersion,
	iconTheProgram,
	"This package installs TeachText in a folder with a custom icon. "
};

resource 'ICON' (iconTheProgram) {
		$"0430 4000 0A50 A000 0B91 1002 0822 0803"
		$"1224 0405 2028 0209 4010 0111 800C 00A1"
		$"8003 FFC2 7E00 FF04 0100 7F04 0300 1E08"
		$"04E0 000C 08E0 000A 10E0 0009 08C0 0006"
		$"0487 FE04 0288 0104 0188 0084 0088 0044"
		$"0088 0044 0088 00C4 0110 0188 0228 0310"
		$"01C4 04E0 0002 0800 73BF FBEE 4CA2 8A2A"
		$"40AA AAEA 52AA AA24 5EA2 8AEA 73BE FB8E",
};


/********************************************* File Specs ******************************************/
/* Source File Specs */
resource 'infs' (fsSourceProgram) {
	'APPL',								/* File Type */
	'ttxt',								/* Creator */
	kScriptCheckSetsDate,				/* ScriptCheck fills in the creation date */
	noSearchForFile,					/* Do not search the source disk for the file */
	typeCrMustMatch,					/* file type and creator on source disk must match */
	ProgramDisk"TeachText"				/* Path to the file */
};

resource 'infs' (fsSourceIcon) {
	'    ',								/* File Type */
	'    ',								/* Creator */
	kScriptCheckSetsDate,				/* ScriptCheck fills in the creation date */
	noSearchForFile,					/* Do not search the source disk for the file */
	typeCrNeedNotMatch,					/* file type and creator on source disk must match */
	ProgramDisk"Icon Folder:Icon\n"		/* Path to the file */
};

/* Target File Specs */
resource 'infs' (fsTargetProgram) {
	'APPL',								/* File Type */
	'ttxt',								/* Creator */
	kNoDateStampCheck,					/* creation date must be zero for target file spec */
	noSearchForFile,					/* Do not search the target disk for the file */
	typeCrNeedNotMatch,					/* file to be replaced even if F&C don't match  */
	TargetPath"TeachText"				/* destination Path */
};
resource 'infs' (fsTargetIcon) {
	'    ',								/* File Type */
	'    ',								/* Creator */
	kNoDateStampCheck,					/* creation date must be zero for target file spec */
	noSearchForFile,					/* Do not search the target disk for the file */
	typeCrNeedNotMatch,					/* file to be replaced even if F&C don't match  */
	TargetPath"Icon\n"					/* destination Path */
};

/******************************************** File Atoms ************************************************/
resource 'infa' (faProgram) {
	format0 {
		StdRemLeaveNewerCopy,			/* see InstallerCommon.r */
		fsTargetProgram,				/* TARGET file spec for this file */
		fsSourceProgram, 				/* SOURCE file spec for this file */
		0,								/* atom size (filled in by ScriptCheck) */
		""								/* Atom Description (Installer will use file name) */
	};
};


resource 'infa' (faIcon) {
	format0 {
		StdRemLeaveNewerCopy,			/* see InstallerCommon.r */
		fsTargetIcon,					/* TARGET file spec for this file */
		fsSourceIcon, 					/* SOURCE file spec for this file */
		0,								/* atom size (filled in by ScriptCheck) */
		""								/* Atom Description (Installer will use file name) */
	};
};

resource 'inaa'	(aaSetFolderIcon) {
	format1 {
		continueBusyCursors,
		actAfter,
		dontActOnRemove,
		actOnInstall,
		'infn',
		aaCodeID,
		fsTargetIcon,				/* pass in the 'infs' resource ID of the target folder Icon file */
		"Set Locked Bit of Target file based on target infs resource ID"
	}
};

INCLUDE	"SetFolderIcon.rsrc" 'infn' (10000) AS 'infn' (aaCodeID, $$Attributes);

