/*------------------------------------------------------------------------------
 *
 *	Apple Macintosh Developer Technical Support
 *
 *  Installer 3.4 sample: Action Atoms
 *
 *	File:		SetLockBitAtomSample.r -	Rez Source
 *
 *  Modifications:
 *		5/19/93: RRK Changed Target file spec typeCrMustMatch flag setting to
 *						typeCrNeedNotMatch and included comment that this will
 *						allow the replacement of the target file if for some reason
 *						the file or creator are different.
 *					 Used InstallerCommon.r defines.
 *
 *	by:			Rich Kubota
 *
 *	Copyright  1992 Apple Computer, Inc.
 *	All rights reserved.
 *
 *------------------------------------------------------------------------------
 *
 * Install application "TheProgram" into the "Root directory and lock the file.
 * For this sample, I use TeachText as the program to install and lock.
 * Demonstrates implementation of an action atom.
 *
 * Note: This action atom sample is only compatible with Installer 3.3 and 3.4
 *----------------------------------------------------------------------------*/
/*

You can build the script with the following lines:

		rez  -o "SetLockBitAtomSample" -t 'bbkr' -c 'bbkr' "SetLockBitAtomSample.r"
		setfile -a i "SetLockBitAtomSample"
		scriptcheck -p "SetLockBitAtomSample"

------------------------------------------------------------------------------------------
*/

#include "Types.r"
#include "InstallerTypes.r"
#include "InstallerCommon.r"		/* list of macros to simplify list */

/* 'inaa' code resource definition */
#define		aaCodeID			10000

/* put a 1 in the creation date field of source 'infs' to have ScriptCheck set date */
#define kScriptCheckSetsDate	0x01

/* Definitions for the file spec atoms (specifications for source and destination files) */
#define fsSourceProgram			2000
#define fsTargetProgram			2001

/* This is the name of the source disk */
#define ProgramDisk "Program Disk:"

/* where we want to install our file. */
#define TargetPath	":"

/* Definition for the package. */
#define pkTheProgram			3000

/* Definition for the file atom */
#define faProgram				4000

/* Definition for the package comment resource */
#define cmtTheProgram			5000

/* Definitions for the action atom resources */
#define aaSetLockBit			6000

/* May 19, 1993 is the current release date I put in 'icmt' rsrcs. ScriptCheck will convert */
/* this value to a LongInt seconds value needed by the Installer. */
#define currentReleaseDate		5191993	
#define currentVersion			102 	/* Version 1.0.2 goes in the 'icmt' rsrc */

#define iconTheProgram			5100

/************************** Easy Install Rule resources **********************************/

/***************************** Package Resources ************************************************/
resource 'inpk' (pkTheProgram) {
	format0 {
		ShowsOnCustom, 				/* Package appears in the Custom Install display */
		Removable,					/* Package can be removed */
		dontForceRestart,			/* no need to restart */
		cmtTheProgram, 				/* package's 'icmt' resource id */
		0,							/* Package size (filled in by ScriptCheck) */
		"TheProgram", {				/* package name for package that shows on custom */
			'infa', faProgram;
			'inaa', aaSetLockBit;
		}
	}
};

/***************************** Comments ************************************************/
resource 'icmt' (cmtTheProgram) {
	currentReleaseDate,
	currentVersion,
	iconTheProgram,
	"This package contains TheProgram. "
};

resource 'ICON' (iconTheProgram) {
		$"0430 4000 0A50 A000 0B91 1002 0822 0803"
		$"1224 0405 2028 0209 4010 0111 800C 00A1"
		$"8003 FFC2 7E00 FF04 0100 7F04 0300 1E08"
		$"04E0 000C 08E0 000A 10E0 0009 08C0 0006"
		$"0487 FE04 0288 0104 0188 0084 0088 0044"
		$"0088 0044 0088 00C4 0110 0188 0228 0310"
		$"01C4 04E0 0002 0800 73BF FBEE 4CA2 8A2A"
		$"40AA AAEA 52AA AA24 5EA2 8AEA 73BE FB8E",
};


/********************************************* File Specs ******************************************/
/* Source File Specs */
resource 'infs' (fsSourceProgram) {
	'APPL',								/* File Type */
	'ttxt',								/* Creator */
	kScriptCheckSetsDate,				/* ScriptCheck fills in the creation date */
	noSearchForFile,					/* Do not search the source disk for the file */
	TypeCrMustMatch,					/* file type and creator on source disk must match */
	ProgramDisk"TeachText"				/* Path to the file */
};

/* Target File Specs */
resource 'infs' (fsTargetProgram) {
	'APPL',								/* File Type */
	'ttxt',								/* Creator */
	kNoDateStampCheck,					/* creation date must be zero for target file spec */
	noSearchForFile,					/* Do not search the target disk for the file */
	typeCrNeedNotMatch,					/* file to be replaced even if F&C don't match  */
	TargetPath"TeachText"				/* destination Path */
};

/******************************************** File Atoms ************************************************/
resource 'infa' (faProgram) {
	format0 {
		StdRemLeaveNewerCopy,			/* see InstallerCommon.r */
		fsTargetProgram,				/* TARGET file spec for this file */
		fsSourceProgram, 				/* SOURCE file spec for this file */
		0,								/* atom size (filled in by ScriptCheck) */
		""								/* Atom Description (Installer will use file name) */
	};
};


resource 'inaa'	(aaSetLockBit) {
	format1 {
		continueBusyCursors,
		actAfter,
		dontActOnRemove,
		actOnInstall,
		'infn',
		aaCodeID,
		fsTargetProgram,				/* pass in the 'infs' resource ID of the file to lock */
		"Set Locked Bit of Target file based on target infs resource ID"
	}
};

INCLUDE	"SetLockBit.rsrc" 'infn' (10000) AS 'infn' (aaCodeID, $$Attributes);

