/*------------------------------------------------------------------------------
 *
 *	Apple Macintosh Developer Technical Support
 *
 *  Installer 3.2 sample: Action Atoms
 *
 *	File:		ActionAtomSample.r -	Rez Source
 *
 *	by:		 Jon Zap
 *  updated for use with Installer 3.4 by: Rich Kubota 9/8/92
 *		    rrk - 5/19/93 Changed Target file spec typeCrMustMatch flag setting to
 *						typeCrNeedNotMatch and included comment that this will
 *						allow the replacement of the target file if for some reason
 *						the file or creator are different.
 *					 Used InstallerCommon.r defines.
 *			rrk - 9/8/92 changed inaa to reference format1 instead of format0.
 *					Added suspendBusyCursors flag to have arrow cursor displayed
 *					during the dialog.
 *
 *	Copyright  1991 Apple Computer, Inc.
 *	All rights reserved.
 *
 *------------------------------------------------------------------------------
 *
 * Install application "TheProgram" into the folder "Root":Installed Application.
 * It demonstrates implementation of an action atom.
 *----------------------------------------------------------------------------*/
/*

You can build the script with the following lines:

		rez  -o "ActionAtomSample" -t 'bbkr' -c 'bbkr' "ActionAtomSample.r"
		setfile -a i "ActionAtomSample"
		scriptcheck -p "ActionAtomSample"

------------------------------------------------------------------------------------------
*/

#include "Types.r"
#include "InstallerTypes.r"
#include "ActionAtomSelectors.h"
#include "InstallerCommon.r"		/* list of macros to simplify list */

/* 'inaa' code resource definition */
#define		aaCodeID				128

/* Definitions for the file spec atoms (specifications for source and destination files) */
#define fsSourceProgram			2000
#define fsTargetProgram			2001

/* This is the name of the source disk */
#define ProgramDisk "Program Disk:"

/* where we want to install our file. */
#define TargetPath	":Installed Application:"

/* Definition for the package. */
#define pkTheProgram			3000

/* Definition for the file atom */
#define faProgram				4000

/* Definition for the package comment resource */
#define cmtTheProgram			5000

/* Definitions for the action atom resources */
#define aaAlertID				6000

/* May 19, 1993 is the current release date I put in 'icmt' rsrcs. ScriptCheck will convert */
/* this value to a LongInt seconds value needed by the Installer. */
#define currentReleaseDate		5191993	
#define currentVersion			102 	/* Version 1.0.2 goes in the 'icmt' rsrc */

#define iconTheProgram			5100

/************************** Easy Install Rule resources **********************************/

/***************************** Package Resources ************************************************/
resource 'inpk' (pkTheProgram) {
	format0 {
		ShowsOnCustom, 				/* Package appears in the Custom Install display */
		Removable,					/* Package can be removed */
		dontForceRestart,			/* no need to restart */
		cmtTheProgram, 				/* package's 'icmt' resource id */
		0,							/* Package size (filled in by ScriptCheck) */
		"TheProgram", {				/* package name for package that shows on custom */
			'infa', faProgram;
			'inaa', aaAlertID;
		}
	}
};

/***************************** Comments ************************************************/
resource 'icmt' (cmtTheProgram) {
	currentReleaseDate,
	currentVersion,
	iconTheProgram,
	"This package installs TeachText. "
};

resource 'ICON' (iconTheProgram) {
		$"0430 4000 0A50 A000 0B91 1002 0822 0803"
		$"1224 0405 2028 0209 4010 0111 800C 00A1"
		$"8003 FFC2 7E00 FF04 0100 7F04 0300 1E08"
		$"04E0 000C 08E0 000A 10E0 0009 08C0 0006"
		$"0487 FE04 0288 0104 0188 0084 0088 0044"
		$"0088 0044 0088 00C4 0110 0188 0228 0310"
		$"01C4 04E0 0002 0800 73BF FBEE 4CA2 8A2A"
		$"40AA AAEA 52AA AA24 5EA2 8AEA 73BE FB8E",
};


/********************************************* File Specs ******************************************/
/* Source File Specs */
resource 'infs' (fsSourceProgram) {
	'APPL',								/* File Type */
	'ttxt',								/* Creator */
	kScriptCheckSetsDate,				/* ScriptCheck fills in the creation date */
	noSearchForFile,					/* Do not search the source disk for the file */
	TypeCrMustMatch,					/* file type and creator on source disk must match */
	ProgramDisk"TeachText"				/* Path to the file */
};

/* Target File Specs */
resource 'infs' (fsTargetProgram) {
	'APPL',								/* File Type */
	'ttxt',								/* Creator */
	kNoDateStampCheck,					/* creation date must be zero for target file spec */
	noSearchForFile,					/* Do not search the target disk for the file */
	typeCrNeedNotMatch,					/* file to be replaced even if F&C don't match  */
	TargetPath"TeachText"				/* destination Path */
};

/******************************************** File Atoms ************************************************/
resource 'infa' (faProgram) {
	format0 {
		StdRemLeaveNewerCopy,			/* see InstallerCommon.r */
		fsTargetProgram,				/* TARGET file spec for this file */
		fsSourceProgram, 				/* SOURCE file spec for this file */
		0,								/* atom size (filled in by ScriptCheck) */
		""								/* Atom Description (Installer will use file name) */
	};
};


resource 'inaa'	(aaAlertID) {
	format1 {
		suspendBusyCursors,
		actBefore,
		dontActOnRemove,
		actOnInstall,
		'infn',
		aaCodeID,
		ShowAlertSelector,
		"Display message to user."
	}
};

/* Note that since the action atom is listed as actBefore, the Installer will not call
   it with a cleanUpCancel message.  For this to happen you need to implement and
   Action atom with the actAfter flag set.
 */

resource 'ALRT' (aaCodeID) {
	{0, 0, 150, 360},
		aaCodeID,
	{
		OK, visible, sound1,
		OK, visible, sound1,
		OK, visible, sound1,
		OK, visible, sound1
	}
};

resource 'DITL' (aaCodeID) {
	{
		{122, 280, 142, 348}, Button { enabled, "OK" },
		{8, 64, 96, 348}, StaticText { disabled, "This space available." }
	}
};

INCLUDE	"ActionAtomSample.rsrc" 'infn' (1001) AS 'infn' (aaCodeID, $$Attributes);

