/*------------------------------------------------------------------------------
 *
 *	Apple Macintosh Developer Technical Support
 *
 *  Installer 3.2 sample: demonstrates installing an INIT into the appropriate folder
 *
 *	File:		InstallINIT.r -	Rez Source
 *
 *  Modifications:
 *		5/19/93: RRK Changed Target file spec typeCrMustMatch flag setting to
 *						typeCrNeedNotMatch and included comment that this will
 *						allow the replacement of the target file if for some reason
 *						the file or creator are different.
 *					 Used InstallerCommon.r defines.
 *
 *	by:			Jon Zap
 *  updated for use with Installer 3.4 by: Rich Kubota 9/1/92
 *
 *	Copyright  1991 Apple Computer, Inc.
 *	All rights reserved.
 *
 *------------------------------------------------------------------------------
 * This sample installs "TheINIT" into the appropriate system
 * folder.  It allows for custom installation/removal.  The script implements 
 * so if we specify the extensions folder but it does not exist, the Installer will
 * use the system folder instead. This greatly simplifies the script.
 *----------------------------------------------------------------------------*/

#include "Types.r"					/* for the ICON resource */
#include "InstallerTypes.r"
#include "InstallerCommon.r"		/* list of macros to simplify list */

/* You can build and complete the script with the following lines:
# Note: set up floppies with the appropriate names and contents before running scriptcheck
# or set up folders with the same names and contents as the floppies
# put these folders in the same folder as the script or at the root directory of same disk

	rez -o "InstallINIT" -t 'bbkr' -c 'bbkr' "InstallINIT.r"
	setfile -a i "InstallINIT"		#mark Inited
	scriptcheck -p "InstallINIT"
*/

/* Definitions for the rules */
#define rlAddInit				1000

/* Defines for the file spec atoms.  These are specifications for source and destination files */
#define fsSourceINIT			2000
#define fsTargetINIT			2001

/* This is the name of the source disk */
#define INITDisk "INIT Disk:"

/* where we want to install our file. */
#define TargetPath	"special-extn:"

/* Definition for the package. */
#define pkTheINIT			3000

/* Definition for the file atom */
#define faINIT				4000

/* Definition for the package comment resource */
#define cmtTheINIT			5000
#define iconTheINIT			6000

/* May 19, 1993 is the current release date I put in 'icmt' rsrcs. ScriptCheck will convert */
/* this value to a LongInt seconds value needed by the Installer. */
#define currentReleaseDate		5191993	
#define currentVersion			102 	/* Version 1.0.2 goes in the 'icmt' rsrc */


/************************** Easy Install Rule resources **********************************/
resource 'infr' (1) {
	format0  {{
		pickAll,	{rlAddInit},	 /* Select the rule */
	}};
};

/* note the '.' in the first rule is missing in the 2nd rule so we can differentiate*/
resource 'inrl' (rlAddInit) {
	format0 {{
		addUserDescription {"Click Install button to install\n"}, /* message to appear in Easy Install screen */
		addUserDescription {" The INIT.\n"},	/* message to appear in Easy Install screen */
		addPackages {{pkTheINIT}}			/* we're installing the INIT */
	}};
};

/***************************** Package Resources ************************************************/
resource 'inpk' (pkTheINIT) {
	format0 {
		ShowsOnCustom, 					/* Package appears in the Custom Install display */
		Removable,						/* Package can be removed */
		forceRestart,					/* so we actually activate the init */
		cmtTheINIT, 					/* package's 'icmt' resource id */
		0,								/* Package size (filled in by ScriptCheck) */
		"Install TheINIT", { /* package name for package that shows on custom */
			'infa', faINIT;
		}
	}
};

/***************************** Comments ************************************************/
resource 'icmt' (cmtTheINIT) {
	currentReleaseDate,
	currentVersion,
	iconTheINIT,
	"This package contains TheINIT. "
};

resource 'ICON' (iconTheINIT) {
		$"0430 4000 0A50 A000 0B91 1002 0822 0803"
		$"1224 0405 2028 0209 4010 0111 800C 00A1"
		$"8003 FFC2 7E00 FF04 0100 7F04 0300 1E08"
		$"04E0 000C 08E0 000A 10E0 0009 08C0 0006"
		$"0487 FE04 0288 0104 0188 0084 0088 0044"
		$"0088 0044 0088 00C4 0110 0188 0228 0310"
		$"01C4 04E0 0002 0800 73BF FBEE 4CA2 8A2A"
		$"40AA AAEA 52AA AA24 5EA2 8AEA 73BE FB8E",
};



/********************************************* File Specs *******************************************/
/* Source File Specs */
resource 'infs' (fsSourceINIT) {
	'INIT',								/* File Type */
	'????',								/* Creator */
	kScriptCheckSetsDate,				/* ScriptCheck fills in the creation date */
	noSearchForFile,					/* Do not search the source disk for the file */
	TypeCrMustMatch,					/* file type and creator on source disk must match */
	INITDisk"TheINIT"					/* Path to the file */
};

/* Target File Specs */
resource 'infs' (fsTargetINIT) {
	'INIT',								/* File Type */
	'????',								/* Creator */
	kNoDateStampCheck,					/* creation date must be zero for target file spec */
	noSearchForFile,					/* Do not search the target disk for the file */
	typeCrNeedNotMatch,					/* file to be replaced even if F&C don't match  */
	TargetPath"TheINIT"					/* destination Path */
};


/******************************************** File Atoms ************************************************/
resource 'infa' (faINIT) {
	format0 {
		StdRemLeaveNewerCopy,			/* see InstallerCommon.r */
		fsTargetINIT,					/* TARGET file spec for this file */
		fsSourceINIT, 					/* SOURCE file spec for this file */
		0,								/* atom size (filled in by ScriptCheck) */
		""								/* Atom Description (Installer will use file name) */
	};
};



