/*------------------------------------------------------------------------------
 *
 *	Apple Macintosh Developer Technical Support
 *
 *  Installer 3.2 sample: very simple installation (Custom Installation only)
 *
 *	File:		SimpleCustomOnly.r -	Rez Source
 *
 *  Modifications:
 *		5/19/93: RRK Changed Target file spec typeCrMustMatch flag setting to
 *						typeCrNeedNotMatch and included comment that this will
 *						allow the replacement of the target file if for some reason
 *						the file or creator are different.
 *					 Used InstallerCommon.r defines.
 *
 *	by:			Jon Zap
 *  updated for use with Installer 3.4 by: Rich Kubota 9/1/92
 *
 *	Copyright  1991 Apple Computer, Inc.
 *	All rights reserved.
 *
 *------------------------------------------------------------------------------
 *
 * Install application "TheProgram" into the folder "Root":Installed Application
 * It demonstrates only Custom Installation (Easy Installation is not supported)
 * Note: we are not recommending that you do a custom only installation; it is
 * here to show what is needed for custom installation.  (The key point is that
 * frameworks and rules do not apply)
 *----------------------------------------------------------------------------*/

#include "InstallerTypes.r"
#include "InstallerCommon.r"		/* list of macros to simplify list */

/* You can build and complete the script with the following lines:
# Note: set up floppies with the appropriate names and contents before running scriptcheck
# or set up folders with the same names and contents as the floppies
# put these folders in the same folder as the script or at the root directory of same disk

	rez -o "SimpleCustomOnly" -t 'bbkr' -c 'bbkr' "SimpleCustomOnly.r"
	setfile -a i "SimpleCustomOnly"		#mark Inited
	scriptcheck -p "SimpleCustomOnly"
*/

/* Defines for the file spec atoms (specifications for source and destination files) */
#define fsSourceProgram			2000
#define fsTargetProgram			2001

/* This is the name of the source disk */
#define ProgramDisk "Program Disk:"

/* This is the target path for where we want to install the file. */
#define TargetPath	":Installed Application:"

/* Definition for the package. */
#define pkTheProgram			3000

/* Definition for the file atom */
#define faProgram				4000

/***************************** Package Resources ************************************************/
resource 'inpk' (pkTheProgram) {
	format0 {
		showsOnCustom, 			/* Package appears in the Custom Install display */
		removable,				/* Package can be removed */
		dontForceRestart,		/* installing an app doesnt require rebooting */
		0, 						/* 'icmt' not required */
		0,						/* Package size (filled in by ScriptCheck) */
		"The Program", {		/* package name */
			'infa', faProgram;
		}
	}
};

/********************************************* File Specs ***************************************/
/* Source File Specs */
resource 'infs' (fsSourceProgram) {
	'APPL',								/* File Type */
	'ttxt',								/* Creator */
	kScriptCheckSetsDate,				/* ScriptCheck will fill in the creation date */
	noSearchForFile,					/* Do not search the source disk for the file */
	typeCrMustMatch,					/* file type and creator on this file must match */
	ProgramDisk"TeachText"				/* Path to the file */
};

/* Target File Specs */
resource 'infs' (fsTargetProgram) {
	'APPL',								/* File Type */
	'ttxt',								/* Creator */
	kNoDateStampCheck,					/* creation date must be zero for target file spec */
	noSearchForFile,					/* Do not search the target disk for the file */
	typeCrNeedNotMatch,					/* file to be replaced even if F&C don't match  */
	TargetPath"TeachText"				/* installation Path */
};

/******************************************** File Atoms ************************************************/
resource 'infa' (faProgram) {
	format0 {
		StdRemLeaveNewerCopy,			/* see InstallerCommon.r */
		fsTargetProgram,				/* TARGET file spec */
		fsSourceProgram, 				/* SOURCE file spec */
		0,								/* atom size (filled in by ScriptCheck) */
		""								/* Atom Description (for a file Installer will use file name) */
	};
};



