/*
	File:		InstallerCommon.r

	Contains:	Some useful definitions for the Installer

	Copyright:	 1991-1992 by Apple Computer, Inc., all rights reserved.

*/

#ifndef __INSTALLERCOMMON__
#define __INSTALLERCOMMON__


/**********************************************************************
** Some Defines for setting the file date/time stamp field
***********************************************************************/
#define kNoDateStampCheck		0x00	/* tells ScriptCheck to leave   */
					/* the creation date field at 0.   A zero value tells */
					/* the installer to not verify the file by this date */
					/* time stamp when preflighting an installation 	*/
					
#define kScriptCheckSetsDate	0x01	/* tells ScriptCheck to fill in */
					/* the creation date field.  A non-zero value tells */
					/* the installer to check that the file has this value */
					/* when preflighting an installation 				*/

/**********************************************************************
** Some Defines to make things more readable
***********************************************************************/

#ifndef StdLeaveNewerCopy
#define StdLeaveNewerCopy		dontDeleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								leaveAloneIfNewer,		\
								updateExisting,			\
								copyifNewOrUpdate,		\
								rsrcFork,				\
								dataFork	
#endif

#ifndef StdCopy
#define StdCopy					dontDeleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								updateEvenIfNewer,		\
								updateExisting,			\
								copyifNewOrUpdate,		\
								rsrcFork,				\
								dataFork	
#endif

#ifndef StdRemLeaveNewerCopy
#define StdRemLeaveNewerCopy	deleteWhenRemoving,	    \
								deleteWhenInstalling,	\
								copy,					\
								leaveAloneIfNewer,		\
								updateExisting,			\
								copyifNewOrUpdate,		\
								rsrcFork,				\
								dataFork	
#endif

#ifndef StdRemCopy
#define StdRemCopy				deleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								updateEvenIfNewer,		\
								updateExisting,			\
								copyifNewOrUpdate,		\
								rsrcFork,				\
								dataFork	
#endif

#ifndef StdDelete
#define StdDelete				deleteWhenRemoving,		\
								deleteWhenInstalling,	\
								dontCopy,				\
								updateEvenIfNewer,		\
								updateExisting,			\
								copyifNewOrUpdate,		\
								rsrcFork,				\
								dataFork
#endif

#ifndef StdResCopy
#define StdResCopy				dontDeleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byID,					\
								nameNeedNotMatch
#endif

#ifndef StdRemResCopy
#define StdRemResCopy			deleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byID,					\
								nameNeedNotMatch
#endif

#ifndef StdResMake
#define StdResMake				dontDeleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								noTgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byID,					\
								nameNeedNotMatch
#endif

#ifndef StdRemResCopyName
#define StdRemResCopyName		deleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byName,					\
								nameMustMatch
#endif

#ifndef StdResCopyName
#define StdResCopyName			dontDeleteWhenRemoving,	\
								dontDeleteWhenInstalling,	\
								copy,					\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byName,					\
								nameMustMatch
#endif

#ifndef StdResDelete
#define StdResDelete			deleteWhenRemoving,		\
								deleteWhenInstalling,	\
								dontCopy,				\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								ignoreProtection,		\
								srcNeedNotExist,		\
								byID,					\
								nameNeedNotMatch
#endif

#ifndef StdFontMake
#define StdFontMake				dontDeleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								noTgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byName,					\
								nameMustMatch
#endif

#ifndef StdFontCopy
#define StdFontCopy				dontDeleteWhenRemoving,	\
								deleteWhenInstalling,	\
								copy,					\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byName,					\
								nameMustMatch
#endif

#ifndef StdRemFontMake
#define StdRemFontMake			deleteWhenRemoving,		\
								deleteWhenInstalling,	\
								copy,					\
								noTgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								dontIgnoreProtection,	\
								srcNeedExist,			\
								byName,					\
								nameMustMatch
#endif

#ifndef StdFontDelete
#define StdFontDelete			deleteWhenRemoving,		\
								deleteWhenInstalling,	\
								dontCopy,				\
								tgtRequired,			\
								updateExisting,			\
								copyIfNewOrUpdate,		\
								ignoreProtection,		\
								srcNeedNotExist,		\
								byName,					\
								nameMustMatch
#endif

#ifndef PlainFontStyle
#define PlainFontStyle			noExtendedStyle,		\
								noCondensedStyle,		\
								noShadowStyle,			\
								noOutlineStyle,			\
								noUnderlineStyle,		\
								noItalicStyle,			\
								noBoldStyle
#endif

#ifndef BoldFontStyle
#define BoldFontStyle			noExtendedStyle,		\
								noCondensedStyle,		\
								noShadowStyle,			\
								noOutlineStyle,			\
								noUnderlineStyle,		\
								noItalicStyle,			\
								boldStyle
#endif

#ifndef ItalicFontStyle
#define ItalicFontStyle			noExtendedStyle,		\
								noCondensedStyle,		\
								noShadowStyle,			\
								noOutlineStyle,			\
								noUnderlineStyle,		\
								italicStyle,			\
								noBoldStyle
#endif

#ifndef BoldItalicFontStyle
#define BoldItalicFontStyle		noExtendedStyle,		\
								noCondensedStyle,		\
								noShadowStyle,			\
								noOutlineStyle,			\
								noUnderlineStyle,		\
								italicStyle,			\
								boldStyle
#endif



#endif